@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: AirportBrowser.cxx 529 2010-01-26 22:00:22Z fredb $
+// $Id: AirportBrowser.cxx 584 2010-12-11 12:48:36Z fredb $
 
 #include <algorithm>
 #include <iterator>
@@ -266,12 +266,6 @@ AirportBrowser::runways_idle_proc( )
                 apt.name_ += " [S]";
             }
 
-            SGPath path = fg_root_;
-            path.append( "AI/Airports" );
-            path.append( apt.id_ );
-            path.append( "parking.xml" );
-            load_parking( path, apt );
-
             airports_.push_back( apt );
         }
         else if (type_num == 10)	// Now read in the runways and taxiways
@@ -608,6 +602,16 @@ AirportBrowser::load_airports( const vector<string>& dirs,
     airports_cache_ = cache;
     airports_loaded_ = false;
 
+    scenery_roots_.clear();
+    for ( vector<string>::const_iterator ii = dirs.begin(); ii != dirs.end(); ++ii )
+    {
+        SGPath p( *ii );
+        if ( p.file() == "Terrain" )
+            scenery_roots_.push_back( p.dir() );
+        else
+            scenery_roots_.push_back( p.str() );
+    }
+
     if (cache.exists())
     {
         bool airports = true;
@@ -776,6 +780,37 @@ AirportBrowser::loaded() const
 }
 
 void
+AirportBrowser::try_load_parking( apt_dat_t &apt )
+{
+    if (apt.id_.length() >= 3)
+    {
+        SGPath pa( "Airports" );
+        pa.append( apt.id_.substr(0,1) );
+        pa.append( apt.id_.substr(1,1) );
+        pa.append( apt.id_.substr(2,1) );
+        pa.append( apt.id_ );
+
+        for ( vector<string>::const_iterator ii = scenery_roots_.begin(); ii != scenery_roots_.end(); ++ii )
+        {
+            SGPath p( *ii ), p2;
+            p.append( pa.str() );
+            p2 = p;
+            p.concat( ".groundnet.xml" );
+            if (load_parking( p, apt ))
+                return;
+            p2.concat( ".parking.xml" );
+            if (load_parking( p2, apt ))
+                return;
+        }
+    }
+    SGPath path = fg_root_;
+    path.append( "AI/Airports" );
+    path.append( apt.id_ );
+    path.append( "parking.xml" );
+    load_parking( path, apt );
+}
+
+bool
 AirportBrowser::load_parking( const SGPath &path, apt_dat_t &data )
 {
     ParkingLoader visitor( data );
@@ -783,22 +818,31 @@ AirportBrowser::load_parking( const SGPath &path, apt_dat_t &data )
     {
         try {
             readXML( path.str(), visitor );
+            return true;
         } catch (const sg_exception &) {
             //cerr << "unable to read " << parkpath.str() << endl;
         }
     }
+    return false;
 }
 
 void
 AirportBrowser::show_parking( const apt_dat_t* apt )
 {
     if (apt == 0 || apt->id_.empty())
-	return;
+        return;
+
+    if ( !apt->parkingRead )
+    {
+        apt_dat_t* apt_ = const_cast<apt_dat_t*>(apt);
+        try_load_parking( *apt_ );
+        apt_->parkingRead = true;
+    }
 
     parking_->clear();
     for ( std::set<std::string>::const_iterator ii = apt->parking_.begin(); ii != apt->parking_.end(); ++ii )
     {
-	parking_->add( ii->c_str() );
+        parking_->add( ii->c_str() );
     }
 }
 
