@@ -23,7 +23,7 @@
 #ifndef i18n_h_included
 #define i18n_h_included
 
-#if defined( HAVE_CONFIG_H ) && !defined( VERSION )
+#if defined( HAVE_CONFIG_H )
 #  include "config.h"
 #endif
 
