@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: settings.cxx 477 2008-11-29 10:27:34Z fredb $
+// $Id: settings.cxx 631 2011-10-08 14:03:54Z fredb $
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
@@ -126,6 +126,12 @@ Advanced::save_settings( Fl_Preferences& prefs )
     prefs.set("uBody", uBody->value());
     prefs.set("vBody", vBody->value());
     prefs.set("wBody", wBody->value());
+    prefs.set("vor", vor->value());
+    prefs.set("ndb", ndb->value());
+    prefs.set("fix", fix->value());
+    prefs.set("offset_distance", offset_distance->value());
+    prefs.set("offset_azimuth", offset_azimuth->value());
+    prefs.set("glideslope", glideslope->value());
 
     prefs.set("clouds", clouds->value());
     prefs.set("clouds3d", clouds3d->value());
@@ -153,6 +159,7 @@ Advanced::save_settings( Fl_Preferences& prefs )
     prefs.set("bpp", bpp->text());
     prefs.set("fov", fov->value());
     prefs.set("texture-filtering", (const char *)texture_filtering->mvalue()->user_data());
+    prefs.set("materials-file", materials_file->value());
 
     prefs.set("time-match-real", time_match_real->value());
     prefs.set("time-offset", time_offset_value->value());
@@ -393,6 +400,18 @@ Advanced::load_settings( Fl_Preferences& prefs )
     vBody->value(buf);
     prefs.get("wBody", buf, "", buflen-1);
     wBody->value(buf);
+    prefs.get("vor", buf, "", buflen-1);
+    vor->value(buf);
+    prefs.get("ndb", buf, "", buflen-1);
+    ndb->value(buf);
+    prefs.get("fix", buf, "", buflen-1);
+    fix->value(buf);
+    prefs.get("offset_distance", buf, "", buflen-1);
+    offset_distance->value(buf);
+    prefs.get("offset_azimuth", buf, "", buflen-1);
+    offset_azimuth->value(buf);
+    prefs.get("glideslope", buf, "", buflen-1);
+    glideslope->value(buf);
 
     prefs.get("clouds", iVal, 1);
     clouds->value(iVal);
@@ -435,6 +454,8 @@ Advanced::load_settings( Fl_Preferences& prefs )
 	vis_miles->setonly();
     prefs.get( "texture-filtering", buf, "1", buflen-1 );
     set_choice_from_data( texture_filtering, buf );
+    prefs.get("materials-file", buf, "", buflen-1);
+    materials_file->value(buf);
 
     prefs.get( "time-match-real", iVal, 1 );
     if (iVal) time_match_real->setonly();
@@ -648,6 +669,12 @@ Advanced::reset_settings( Fl_Preferences& prefs )
     prefs.deleteEntry("uBody" );
     prefs.deleteEntry("vBody" );
     prefs.deleteEntry("wBody" );
+    prefs.deleteEntry("vor" );
+    prefs.deleteEntry("ndb" );
+    prefs.deleteEntry("fix" );
+    prefs.deleteEntry("offset_distance" );
+    prefs.deleteEntry("offset_azimuth" );
+    prefs.deleteEntry("glideslope" );
 
     prefs.deleteEntry("clouds" );
     prefs.deleteEntry("clouds3d" );
@@ -664,6 +691,7 @@ Advanced::reset_settings( Fl_Preferences& prefs )
     prefs.deleteEntry("bpp" );
     prefs.deleteEntry("fov" );
     prefs.deleteEntry("texture-filtering" );
+    prefs.deleteEntry("materials-file" );
 
     prefs.deleteEntry("time-match-real" );
     prefs.deleteEntry("time-offset" );
